Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/tlc59711_simpletest.py
    :caption: examples/tlc59711_simpletest.py
    :linenos:


FancyLED
------------

this is an example for combining the TLC5957 library with FancyLED.
Enjoy the colors :-)

.. literalinclude:: ../examples/tlc59711_fancyled.py
    :caption: examples/tlc59711_fancyled.py
    :linenos:


Animations Example
------------------

You should have a plethora of functions to animate your lights.

.. literalinclude:: ../examples/tlc59711_dev.py
    :caption: examples/tlc59711_dev.py
    :linenos:


Single Chip Autoshow
--------------------

This makes it very slow on lots of pixel changes but is convenient for only a handful of pixels.

.. literalinclude:: ../examples/tlc59711_singlechip_autoshow.py
    :caption: examples/tlc59711_singlechip_autoshow.py
    :linenos:


Brightness Correction Data
--------------------------

Test brightness correction data (BC)

.. literalinclude:: ../examples/tlc59711_simpletest.py
    :caption: examples/tlc59711_simpletest.py
    :linenos:

Fastset test
------------

Showcases the usage of set_pixel_16bit_value for fastest setting of values.

.. literalinclude:: ../examples/tlc59711_fastset.py
    :caption: examples/tlc59711_fastset.py
    :linenos:
